# Collection of digitized data from published work

## Digitization protocol:

**Tool**: Webplotdigitizer https://automeris.io/WebPlotDigitizer/

[![](http://img.youtube.com/vi/jKtmEz6jeCs/0.jpg)](http://www.youtube.com/watch?v=jKtmEz6jeCs "plot_digitizer_demo")

## Initial scope:

Initially collecting just flow curve for yield stress fluids,
viscosity or shear stress as a function of shear rate or shear stress

File structure:

* folder with published article name (need to decide name convention)
  * weplot difitizer exported file: Naming convention DOI_fig#a_xlabel_xunits_ylabel_yunits.csv
